PAWpySeed: real_proj_site Struct Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Attributes | List of all members
real_proj_site Struct Reference

`#include <utils.h>`

Collaboration diagram for real_proj_site:
[legend]

## Public Attributes
int | index
int | elem
int | num_projs
int | total_projs
int | num_indices
int | gridsize
double | rmax
double * | coord
int * | indices
real_proj_t * | projs

## Member Data Documentation

double* real_proj_site::coord

int real_proj_site::elem

int real_proj_site::gridsize

int real_proj_site::index

int* real_proj_site::indices

int real_proj_site::num_indices

int real_proj_site::num_projs

real_proj_t* real_proj_site::projs

double real_proj_site::rmax

int real_proj_site::total_projs

The documentation for this struct was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/core/utils.h